@@ -7,7 +7,7 @@ from PythonExtensions.debug import *
 __all__ = ['test_files']
 
 def test_files():
-    _file = File.TemporaryFile('PythonExtensions', name='test.txt')
+    _file = FileIO.TemporaryFile('PythonExtensions', name='test.txt')
     _file.Write('test data')
 
-    PrettyPrint(Path.ListDir('.'))
+    PrettyPrint(FilePath.ListDir('.'))
